@@ -1,5 +1,6 @@
 import re
-
+import os
+    
 class Compiler(object):
     RE_INTERPOLATE = re.compile(r'(\\)?([#!]){(.*?)}')
     doctypes = {
@@ -65,6 +66,7 @@ class Compiler(object):
         self.autocloseCode.extend(options.get('autocloseCode',[]))
         self.inlineTags.extend(options.get('inlineTags',[]))
         self.staticAttrs = options.get('staticAttrs', False)
+        self.extension = options.get('extension', None) or '.jade'
         self.indents = 0
         self.doctype = None
         self.terse = False
@@ -148,7 +150,7 @@ class Compiler(object):
                 self.visitDoctype()
             self.hasCompiledTag = True
 
-        if self.pp and name not in self.inlineTags:
+        if self.pp and name not in self.inlineTags and not tag.inline:
             self.buffer('\n'+'  '*(self.indents-1))
 
         closed = name in self.selfClosing and not self.xml
@@ -207,11 +209,19 @@ class Compiler(object):
     def visitAssignment(self,assignment):
         self.buffer('{%% set %s = %s %%}'%(assignment.name,assignment.val))
 
+
+    def format_path(self,path):
+        has_extension = os.path.basename(path).find('.')>-1
+        if not has_extension: path += self.extension
+        return path
+
     def visitExtends(self,node):
-        self.buffer('{%% extends "%s" %%}'%(node.path))
+        path = self.format_path(node.path)
+        self.buffer('{%% extends "%s" %%}'%(path))
 
     def visitInclude(self,node):
-        self.buffer('{%% include "%s" %%}'%(node.path))
+        path = self.format_path(node.path)
+        self.buffer('{%% include "%s" %%}'%(path))
 
     def visitBlockComment(self,comment):
         if not comment.buffer: return
@@ -284,11 +294,18 @@ class Compiler(object):
     def visitAttributes(self,attrs):
         temp_attrs = []
         for attr in attrs:
-            if self.staticAttrs or attr['static']:
+            if attr['static']:
                 if temp_attrs:
                     self.visitDynamicAttributes(temp_attrs)
                     temp_attrs = []
-                self.buf.append(' %s=%s'%(attr['name'],attr['val']))
+                n,v = attr['name'], attr['val']
+                if isinstance(v,basestring):
+                    self.buf.append(' %s=%s'%(n,v))
+                elif v is True:
+                    if self.terse:
+                        self.buf.append(' %s'%(n))
+                    else:
+                        self.buf.append(' %s="%s"'%(n,n))
             else:
                 temp_attrs.append(attr)
         
