@@ -41,12 +41,6 @@ class Compiler(_Compiler):
     def visitAssignment(self,assignment):
         self.buffer('{%% set %s = %s %%}'%(assignment.name,assignment.val))
 
-    def visitExtends(self,node):
-        self.buffer('{%% extends "%s" %%}'%(node.path))
-
-    def visitInclude(self,node):
-        self.buffer('{%% include "%s" %%}'%(node.path))
-
     def visitCode(self,code):
         if code.buffer:
             val = code.val.lstrip()
